# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RewriteUrlRuleArgs', 'RewriteUrlRule']

@pulumi.input_type
class RewriteUrlRuleArgs:
    def __init__(__self__, *,
                 site_id: pulumi.Input[builtins.int],
                 query_string: Optional[pulumi.Input[builtins.str]] = None,
                 rewrite_query_string_type: Optional[pulumi.Input[builtins.str]] = None,
                 rewrite_uri_type: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a RewriteUrlRule resource.
        :param pulumi.Input[builtins.int] site_id: The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        :param pulumi.Input[builtins.str] query_string: The desired query string to which you want to rewrite the query string in the original request.
        :param pulumi.Input[builtins.str] rewrite_query_string_type: Query string rewrite type. Value range:
        :param pulumi.Input[builtins.str] rewrite_uri_type: URI rewrite type. Value range:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               ● Match all incoming requests: value set to true
               ● Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Indicates whether the rule is enabled. Valid values:
               
               - on
               - off
        :param pulumi.Input[builtins.str] rule_name: The rule name. You do not need to set this parameter when adding a global configuration.
        :param pulumi.Input[builtins.int] site_version: Version number of the site configuration. For a site with configuration version management enabled, you can use this parameter to specify the site version in which the configuration takes effect. The default version is 0.
        :param pulumi.Input[builtins.str] uri: The desired URI to which you want to rewrite the path in the original request.
        """
        pulumi.set(__self__, "site_id", site_id)
        if query_string is not None:
            pulumi.set(__self__, "query_string", query_string)
        if rewrite_query_string_type is not None:
            pulumi.set(__self__, "rewrite_query_string_type", rewrite_query_string_type)
        if rewrite_uri_type is not None:
            pulumi.set(__self__, "rewrite_uri_type", rewrite_uri_type)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)
        if uri is not None:
            pulumi.set(__self__, "uri", uri)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="queryString")
    def query_string(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The desired query string to which you want to rewrite the query string in the original request.
        """
        return pulumi.get(self, "query_string")

    @query_string.setter
    def query_string(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "query_string", value)

    @property
    @pulumi.getter(name="rewriteQueryStringType")
    def rewrite_query_string_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Query string rewrite type. Value range:
        """
        return pulumi.get(self, "rewrite_query_string_type")

    @rewrite_query_string_type.setter
    def rewrite_query_string_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rewrite_query_string_type", value)

    @property
    @pulumi.getter(name="rewriteUriType")
    def rewrite_uri_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        URI rewrite type. Value range:
        """
        return pulumi.get(self, "rewrite_uri_type")

    @rewrite_uri_type.setter
    def rewrite_uri_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rewrite_uri_type", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        ● Match all incoming requests: value set to true
        ● Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Indicates whether the rule is enabled. Valid values:

        - on
        - off
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The rule name. You do not need to set this parameter when adding a global configuration.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Version number of the site configuration. For a site with configuration version management enabled, you can use this parameter to specify the site version in which the configuration takes effect. The default version is 0.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)

    @property
    @pulumi.getter
    def uri(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The desired URI to which you want to rewrite the path in the original request.
        """
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "uri", value)


@pulumi.input_type
class _RewriteUrlRuleState:
    def __init__(__self__, *,
                 config_id: Optional[pulumi.Input[builtins.int]] = None,
                 query_string: Optional[pulumi.Input[builtins.str]] = None,
                 rewrite_query_string_type: Optional[pulumi.Input[builtins.str]] = None,
                 rewrite_uri_type: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering RewriteUrlRule resources.
        :param pulumi.Input[builtins.int] config_id: ConfigId
        :param pulumi.Input[builtins.str] query_string: The desired query string to which you want to rewrite the query string in the original request.
        :param pulumi.Input[builtins.str] rewrite_query_string_type: Query string rewrite type. Value range:
        :param pulumi.Input[builtins.str] rewrite_uri_type: URI rewrite type. Value range:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               ● Match all incoming requests: value set to true
               ● Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Indicates whether the rule is enabled. Valid values:
               
               - on
               - off
        :param pulumi.Input[builtins.str] rule_name: The rule name. You do not need to set this parameter when adding a global configuration.
        :param pulumi.Input[builtins.int] site_id: The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        :param pulumi.Input[builtins.int] site_version: Version number of the site configuration. For a site with configuration version management enabled, you can use this parameter to specify the site version in which the configuration takes effect. The default version is 0.
        :param pulumi.Input[builtins.str] uri: The desired URI to which you want to rewrite the path in the original request.
        """
        if config_id is not None:
            pulumi.set(__self__, "config_id", config_id)
        if query_string is not None:
            pulumi.set(__self__, "query_string", query_string)
        if rewrite_query_string_type is not None:
            pulumi.set(__self__, "rewrite_query_string_type", rewrite_query_string_type)
        if rewrite_uri_type is not None:
            pulumi.set(__self__, "rewrite_uri_type", rewrite_uri_type)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)
        if uri is not None:
            pulumi.set(__self__, "uri", uri)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        ConfigId
        """
        return pulumi.get(self, "config_id")

    @config_id.setter
    def config_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "config_id", value)

    @property
    @pulumi.getter(name="queryString")
    def query_string(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The desired query string to which you want to rewrite the query string in the original request.
        """
        return pulumi.get(self, "query_string")

    @query_string.setter
    def query_string(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "query_string", value)

    @property
    @pulumi.getter(name="rewriteQueryStringType")
    def rewrite_query_string_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Query string rewrite type. Value range:
        """
        return pulumi.get(self, "rewrite_query_string_type")

    @rewrite_query_string_type.setter
    def rewrite_query_string_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rewrite_query_string_type", value)

    @property
    @pulumi.getter(name="rewriteUriType")
    def rewrite_uri_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        URI rewrite type. Value range:
        """
        return pulumi.get(self, "rewrite_uri_type")

    @rewrite_uri_type.setter
    def rewrite_uri_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rewrite_uri_type", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        ● Match all incoming requests: value set to true
        ● Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Indicates whether the rule is enabled. Valid values:

        - on
        - off
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The rule name. You do not need to set this parameter when adding a global configuration.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Version number of the site configuration. For a site with configuration version management enabled, you can use this parameter to specify the site version in which the configuration takes effect. The default version is 0.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)

    @property
    @pulumi.getter
    def uri(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The desired URI to which you want to rewrite the path in the original request.
        """
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "uri", value)


@pulumi.type_token("alicloud:esa/rewriteUrlRule:RewriteUrlRule")
class RewriteUrlRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 query_string: Optional[pulumi.Input[builtins.str]] = None,
                 rewrite_query_string_type: Optional[pulumi.Input[builtins.str]] = None,
                 rewrite_uri_type: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ESA Rewrite Url Rule resource.

        For information about ESA Rewrite Url Rule and how to use it, see [What is Rewrite Url Rule](https://www.alibabacloud.com/help/en/edge-security-acceleration/esa/api-esa-2024-09-10-createrewriteurlrule).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        resource_rewrite_url_rule_rate_plan_instance_example = alicloud.esa.RatePlanInstance("resource_RewriteUrlRule_RatePlanInstance_example",
            type="NS",
            auto_renew=False,
            period=1,
            payment_type="Subscription",
            coverage="overseas",
            auto_pay=True,
            plan_name="high")
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        resource_rewrite_url_rule_site_example = alicloud.esa.Site("resource_RewriteUrlRule_Site_example",
            site_name=f"gositecdn-{default['result']}.cn",
            instance_id=resource_rewrite_url_rule_rate_plan_instance_example.id,
            coverage="overseas",
            access_type="NS")
        default_rewrite_url_rule = alicloud.esa.RewriteUrlRule("default",
            rewrite_uri_type="static",
            rewrite_query_string_type="static",
            site_id=resource_rewrite_url_rule_site_example.id,
            rule_name="example",
            rule_enable="on",
            query_string="example=123",
            site_version=0,
            rule="http.host eq \\"video.example.com\\"",
            uri="/image/example.jpg")
        ```

        ## Import

        ESA Rewrite Url Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/rewriteUrlRule:RewriteUrlRule example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] query_string: The desired query string to which you want to rewrite the query string in the original request.
        :param pulumi.Input[builtins.str] rewrite_query_string_type: Query string rewrite type. Value range:
        :param pulumi.Input[builtins.str] rewrite_uri_type: URI rewrite type. Value range:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               ● Match all incoming requests: value set to true
               ● Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Indicates whether the rule is enabled. Valid values:
               
               - on
               - off
        :param pulumi.Input[builtins.str] rule_name: The rule name. You do not need to set this parameter when adding a global configuration.
        :param pulumi.Input[builtins.int] site_id: The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        :param pulumi.Input[builtins.int] site_version: Version number of the site configuration. For a site with configuration version management enabled, you can use this parameter to specify the site version in which the configuration takes effect. The default version is 0.
        :param pulumi.Input[builtins.str] uri: The desired URI to which you want to rewrite the path in the original request.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RewriteUrlRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Rewrite Url Rule resource.

        For information about ESA Rewrite Url Rule and how to use it, see [What is Rewrite Url Rule](https://www.alibabacloud.com/help/en/edge-security-acceleration/esa/api-esa-2024-09-10-createrewriteurlrule).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        resource_rewrite_url_rule_rate_plan_instance_example = alicloud.esa.RatePlanInstance("resource_RewriteUrlRule_RatePlanInstance_example",
            type="NS",
            auto_renew=False,
            period=1,
            payment_type="Subscription",
            coverage="overseas",
            auto_pay=True,
            plan_name="high")
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        resource_rewrite_url_rule_site_example = alicloud.esa.Site("resource_RewriteUrlRule_Site_example",
            site_name=f"gositecdn-{default['result']}.cn",
            instance_id=resource_rewrite_url_rule_rate_plan_instance_example.id,
            coverage="overseas",
            access_type="NS")
        default_rewrite_url_rule = alicloud.esa.RewriteUrlRule("default",
            rewrite_uri_type="static",
            rewrite_query_string_type="static",
            site_id=resource_rewrite_url_rule_site_example.id,
            rule_name="example",
            rule_enable="on",
            query_string="example=123",
            site_version=0,
            rule="http.host eq \\"video.example.com\\"",
            uri="/image/example.jpg")
        ```

        ## Import

        ESA Rewrite Url Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/rewriteUrlRule:RewriteUrlRule example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param RewriteUrlRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RewriteUrlRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 query_string: Optional[pulumi.Input[builtins.str]] = None,
                 rewrite_query_string_type: Optional[pulumi.Input[builtins.str]] = None,
                 rewrite_uri_type: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RewriteUrlRuleArgs.__new__(RewriteUrlRuleArgs)

            __props__.__dict__["query_string"] = query_string
            __props__.__dict__["rewrite_query_string_type"] = rewrite_query_string_type
            __props__.__dict__["rewrite_uri_type"] = rewrite_uri_type
            __props__.__dict__["rule"] = rule
            __props__.__dict__["rule_enable"] = rule_enable
            __props__.__dict__["rule_name"] = rule_name
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["site_version"] = site_version
            __props__.__dict__["uri"] = uri
            __props__.__dict__["config_id"] = None
        super(RewriteUrlRule, __self__).__init__(
            'alicloud:esa/rewriteUrlRule:RewriteUrlRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config_id: Optional[pulumi.Input[builtins.int]] = None,
            query_string: Optional[pulumi.Input[builtins.str]] = None,
            rewrite_query_string_type: Optional[pulumi.Input[builtins.str]] = None,
            rewrite_uri_type: Optional[pulumi.Input[builtins.str]] = None,
            rule: Optional[pulumi.Input[builtins.str]] = None,
            rule_enable: Optional[pulumi.Input[builtins.str]] = None,
            rule_name: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            site_version: Optional[pulumi.Input[builtins.int]] = None,
            uri: Optional[pulumi.Input[builtins.str]] = None) -> 'RewriteUrlRule':
        """
        Get an existing RewriteUrlRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] config_id: ConfigId
        :param pulumi.Input[builtins.str] query_string: The desired query string to which you want to rewrite the query string in the original request.
        :param pulumi.Input[builtins.str] rewrite_query_string_type: Query string rewrite type. Value range:
        :param pulumi.Input[builtins.str] rewrite_uri_type: URI rewrite type. Value range:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               ● Match all incoming requests: value set to true
               ● Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Indicates whether the rule is enabled. Valid values:
               
               - on
               - off
        :param pulumi.Input[builtins.str] rule_name: The rule name. You do not need to set this parameter when adding a global configuration.
        :param pulumi.Input[builtins.int] site_id: The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        :param pulumi.Input[builtins.int] site_version: Version number of the site configuration. For a site with configuration version management enabled, you can use this parameter to specify the site version in which the configuration takes effect. The default version is 0.
        :param pulumi.Input[builtins.str] uri: The desired URI to which you want to rewrite the path in the original request.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RewriteUrlRuleState.__new__(_RewriteUrlRuleState)

        __props__.__dict__["config_id"] = config_id
        __props__.__dict__["query_string"] = query_string
        __props__.__dict__["rewrite_query_string_type"] = rewrite_query_string_type
        __props__.__dict__["rewrite_uri_type"] = rewrite_uri_type
        __props__.__dict__["rule"] = rule
        __props__.__dict__["rule_enable"] = rule_enable
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["site_version"] = site_version
        __props__.__dict__["uri"] = uri
        return RewriteUrlRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> pulumi.Output[builtins.int]:
        """
        ConfigId
        """
        return pulumi.get(self, "config_id")

    @property
    @pulumi.getter(name="queryString")
    def query_string(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The desired query string to which you want to rewrite the query string in the original request.
        """
        return pulumi.get(self, "query_string")

    @property
    @pulumi.getter(name="rewriteQueryStringType")
    def rewrite_query_string_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Query string rewrite type. Value range:
        """
        return pulumi.get(self, "rewrite_query_string_type")

    @property
    @pulumi.getter(name="rewriteUriType")
    def rewrite_uri_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        URI rewrite type. Value range:
        """
        return pulumi.get(self, "rewrite_uri_type")

    @property
    @pulumi.getter
    def rule(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        ● Match all incoming requests: value set to true
        ● Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Indicates whether the rule is enabled. Valid values:

        - on
        - off
        """
        return pulumi.get(self, "rule_enable")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The rule name. You do not need to set this parameter when adding a global configuration.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Version number of the site configuration. For a site with configuration version management enabled, you can use this parameter to specify the site version in which the configuration takes effect. The default version is 0.
        """
        return pulumi.get(self, "site_version")

    @property
    @pulumi.getter
    def uri(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The desired URI to which you want to rewrite the path in the original request.
        """
        return pulumi.get(self, "uri")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WorkspaceModelVersionArgs', 'WorkspaceModelVersion']

@pulumi.input_type
class WorkspaceModelVersionArgs:
    def __init__(__self__, *,
                 model_id: pulumi.Input[builtins.str],
                 uri: pulumi.Input[builtins.str],
                 approval_status: Optional[pulumi.Input[builtins.str]] = None,
                 extra_info: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 format_type: Optional[pulumi.Input[builtins.str]] = None,
                 framework_type: Optional[pulumi.Input[builtins.str]] = None,
                 inference_spec: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceModelVersionLabelArgs']]]] = None,
                 metrics: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 options: Optional[pulumi.Input[builtins.str]] = None,
                 source_id: Optional[pulumi.Input[builtins.str]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 training_spec: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 version_description: Optional[pulumi.Input[builtins.str]] = None,
                 version_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a WorkspaceModelVersion resource.
        :param pulumi.Input[builtins.str] model_id: The model ID.
        :param pulumi.Input[builtins.str] uri: The URI of the model version.
        :param pulumi.Input[builtins.str] approval_status: The approval status. Valid values:
               - Pending: To be determined.
               - Approved: Allow to go online.
               - Rejected: Online is not allowed.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] extra_info: Other information.
        :param pulumi.Input[builtins.str] format_type: The format of the model. Valid values:
               - OfflineModel
               - SavedModel
               - Keras H5
               - Frozen Pb
               - Caffe Prototxt
               - TorchScript
               - XGBoost
               - PMML
               - AlinkModel
               - ONNX
        :param pulumi.Input[builtins.str] framework_type: The framework of the model. Valid values:
               - Pytorch
               - XGBoost
               - Keras
               - Caffe
               - Alink
               - Xflow
               - TensorFlow
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] inference_spec: Describes how to apply to downstream inference services.
        :param pulumi.Input[Sequence[pulumi.Input['WorkspaceModelVersionLabelArgs']]] labels: List of model version labels. See `labels` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] metrics: The metrics for the model. The serialized length is limited to 8192.
        :param pulumi.Input[builtins.str] options: The extended field. This is a JSON string.
        :param pulumi.Input[builtins.str] source_id: The source ID.
        :param pulumi.Input[builtins.str] source_type: The type of the model source. Valid values:
               - Custom: Custom.
               - PAIFlow:PAI workflow.
               - TrainingService:PAI training service.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] training_spec: The training configurations. Used for fine-tuning and incremental training.
        :param pulumi.Input[builtins.str] version_description: The version descriptions.
        :param pulumi.Input[builtins.str] version_name: The Model version.
        """
        pulumi.set(__self__, "model_id", model_id)
        pulumi.set(__self__, "uri", uri)
        if approval_status is not None:
            pulumi.set(__self__, "approval_status", approval_status)
        if extra_info is not None:
            pulumi.set(__self__, "extra_info", extra_info)
        if format_type is not None:
            pulumi.set(__self__, "format_type", format_type)
        if framework_type is not None:
            pulumi.set(__self__, "framework_type", framework_type)
        if inference_spec is not None:
            pulumi.set(__self__, "inference_spec", inference_spec)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if metrics is not None:
            pulumi.set(__self__, "metrics", metrics)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if source_id is not None:
            pulumi.set(__self__, "source_id", source_id)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if training_spec is not None:
            pulumi.set(__self__, "training_spec", training_spec)
        if version_description is not None:
            pulumi.set(__self__, "version_description", version_description)
        if version_name is not None:
            pulumi.set(__self__, "version_name", version_name)

    @property
    @pulumi.getter(name="modelId")
    def model_id(self) -> pulumi.Input[builtins.str]:
        """
        The model ID.
        """
        return pulumi.get(self, "model_id")

    @model_id.setter
    def model_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "model_id", value)

    @property
    @pulumi.getter
    def uri(self) -> pulumi.Input[builtins.str]:
        """
        The URI of the model version.
        """
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "uri", value)

    @property
    @pulumi.getter(name="approvalStatus")
    def approval_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The approval status. Valid values:
        - Pending: To be determined.
        - Approved: Allow to go online.
        - Rejected: Online is not allowed.
        """
        return pulumi.get(self, "approval_status")

    @approval_status.setter
    def approval_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "approval_status", value)

    @property
    @pulumi.getter(name="extraInfo")
    def extra_info(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Other information.
        """
        return pulumi.get(self, "extra_info")

    @extra_info.setter
    def extra_info(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "extra_info", value)

    @property
    @pulumi.getter(name="formatType")
    def format_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The format of the model. Valid values:
        - OfflineModel
        - SavedModel
        - Keras H5
        - Frozen Pb
        - Caffe Prototxt
        - TorchScript
        - XGBoost
        - PMML
        - AlinkModel
        - ONNX
        """
        return pulumi.get(self, "format_type")

    @format_type.setter
    def format_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "format_type", value)

    @property
    @pulumi.getter(name="frameworkType")
    def framework_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The framework of the model. Valid values:
        - Pytorch
        - XGBoost
        - Keras
        - Caffe
        - Alink
        - Xflow
        - TensorFlow
        """
        return pulumi.get(self, "framework_type")

    @framework_type.setter
    def framework_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "framework_type", value)

    @property
    @pulumi.getter(name="inferenceSpec")
    def inference_spec(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Describes how to apply to downstream inference services.
        """
        return pulumi.get(self, "inference_spec")

    @inference_spec.setter
    def inference_spec(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "inference_spec", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceModelVersionLabelArgs']]]]:
        """
        List of model version labels. See `labels` below.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceModelVersionLabelArgs']]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def metrics(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The metrics for the model. The serialized length is limited to 8192.
        """
        return pulumi.get(self, "metrics")

    @metrics.setter
    def metrics(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "metrics", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The extended field. This is a JSON string.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter(name="sourceId")
    def source_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The source ID.
        """
        return pulumi.get(self, "source_id")

    @source_id.setter
    def source_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_id", value)

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the model source. Valid values:
        - Custom: Custom.
        - PAIFlow:PAI workflow.
        - TrainingService:PAI training service.
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter(name="trainingSpec")
    def training_spec(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The training configurations. Used for fine-tuning and incremental training.
        """
        return pulumi.get(self, "training_spec")

    @training_spec.setter
    def training_spec(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "training_spec", value)

    @property
    @pulumi.getter(name="versionDescription")
    def version_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The version descriptions.
        """
        return pulumi.get(self, "version_description")

    @version_description.setter
    def version_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_description", value)

    @property
    @pulumi.getter(name="versionName")
    def version_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Model version.
        """
        return pulumi.get(self, "version_name")

    @version_name.setter
    def version_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_name", value)


@pulumi.input_type
class _WorkspaceModelVersionState:
    def __init__(__self__, *,
                 approval_status: Optional[pulumi.Input[builtins.str]] = None,
                 extra_info: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 format_type: Optional[pulumi.Input[builtins.str]] = None,
                 framework_type: Optional[pulumi.Input[builtins.str]] = None,
                 inference_spec: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceModelVersionLabelArgs']]]] = None,
                 metrics: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 model_id: Optional[pulumi.Input[builtins.str]] = None,
                 options: Optional[pulumi.Input[builtins.str]] = None,
                 source_id: Optional[pulumi.Input[builtins.str]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 training_spec: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None,
                 version_description: Optional[pulumi.Input[builtins.str]] = None,
                 version_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering WorkspaceModelVersion resources.
        :param pulumi.Input[builtins.str] approval_status: The approval status. Valid values:
               - Pending: To be determined.
               - Approved: Allow to go online.
               - Rejected: Online is not allowed.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] extra_info: Other information.
        :param pulumi.Input[builtins.str] format_type: The format of the model. Valid values:
               - OfflineModel
               - SavedModel
               - Keras H5
               - Frozen Pb
               - Caffe Prototxt
               - TorchScript
               - XGBoost
               - PMML
               - AlinkModel
               - ONNX
        :param pulumi.Input[builtins.str] framework_type: The framework of the model. Valid values:
               - Pytorch
               - XGBoost
               - Keras
               - Caffe
               - Alink
               - Xflow
               - TensorFlow
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] inference_spec: Describes how to apply to downstream inference services.
        :param pulumi.Input[Sequence[pulumi.Input['WorkspaceModelVersionLabelArgs']]] labels: List of model version labels. See `labels` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] metrics: The metrics for the model. The serialized length is limited to 8192.
        :param pulumi.Input[builtins.str] model_id: The model ID.
        :param pulumi.Input[builtins.str] options: The extended field. This is a JSON string.
        :param pulumi.Input[builtins.str] source_id: The source ID.
        :param pulumi.Input[builtins.str] source_type: The type of the model source. Valid values:
               - Custom: Custom.
               - PAIFlow:PAI workflow.
               - TrainingService:PAI training service.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] training_spec: The training configurations. Used for fine-tuning and incremental training.
        :param pulumi.Input[builtins.str] uri: The URI of the model version.
        :param pulumi.Input[builtins.str] version_description: The version descriptions.
        :param pulumi.Input[builtins.str] version_name: The Model version.
        """
        if approval_status is not None:
            pulumi.set(__self__, "approval_status", approval_status)
        if extra_info is not None:
            pulumi.set(__self__, "extra_info", extra_info)
        if format_type is not None:
            pulumi.set(__self__, "format_type", format_type)
        if framework_type is not None:
            pulumi.set(__self__, "framework_type", framework_type)
        if inference_spec is not None:
            pulumi.set(__self__, "inference_spec", inference_spec)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if metrics is not None:
            pulumi.set(__self__, "metrics", metrics)
        if model_id is not None:
            pulumi.set(__self__, "model_id", model_id)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if source_id is not None:
            pulumi.set(__self__, "source_id", source_id)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if training_spec is not None:
            pulumi.set(__self__, "training_spec", training_spec)
        if uri is not None:
            pulumi.set(__self__, "uri", uri)
        if version_description is not None:
            pulumi.set(__self__, "version_description", version_description)
        if version_name is not None:
            pulumi.set(__self__, "version_name", version_name)

    @property
    @pulumi.getter(name="approvalStatus")
    def approval_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The approval status. Valid values:
        - Pending: To be determined.
        - Approved: Allow to go online.
        - Rejected: Online is not allowed.
        """
        return pulumi.get(self, "approval_status")

    @approval_status.setter
    def approval_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "approval_status", value)

    @property
    @pulumi.getter(name="extraInfo")
    def extra_info(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Other information.
        """
        return pulumi.get(self, "extra_info")

    @extra_info.setter
    def extra_info(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "extra_info", value)

    @property
    @pulumi.getter(name="formatType")
    def format_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The format of the model. Valid values:
        - OfflineModel
        - SavedModel
        - Keras H5
        - Frozen Pb
        - Caffe Prototxt
        - TorchScript
        - XGBoost
        - PMML
        - AlinkModel
        - ONNX
        """
        return pulumi.get(self, "format_type")

    @format_type.setter
    def format_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "format_type", value)

    @property
    @pulumi.getter(name="frameworkType")
    def framework_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The framework of the model. Valid values:
        - Pytorch
        - XGBoost
        - Keras
        - Caffe
        - Alink
        - Xflow
        - TensorFlow
        """
        return pulumi.get(self, "framework_type")

    @framework_type.setter
    def framework_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "framework_type", value)

    @property
    @pulumi.getter(name="inferenceSpec")
    def inference_spec(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Describes how to apply to downstream inference services.
        """
        return pulumi.get(self, "inference_spec")

    @inference_spec.setter
    def inference_spec(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "inference_spec", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceModelVersionLabelArgs']]]]:
        """
        List of model version labels. See `labels` below.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceModelVersionLabelArgs']]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def metrics(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The metrics for the model. The serialized length is limited to 8192.
        """
        return pulumi.get(self, "metrics")

    @metrics.setter
    def metrics(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "metrics", value)

    @property
    @pulumi.getter(name="modelId")
    def model_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The model ID.
        """
        return pulumi.get(self, "model_id")

    @model_id.setter
    def model_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "model_id", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The extended field. This is a JSON string.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter(name="sourceId")
    def source_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The source ID.
        """
        return pulumi.get(self, "source_id")

    @source_id.setter
    def source_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_id", value)

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the model source. Valid values:
        - Custom: Custom.
        - PAIFlow:PAI workflow.
        - TrainingService:PAI training service.
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter(name="trainingSpec")
    def training_spec(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The training configurations. Used for fine-tuning and incremental training.
        """
        return pulumi.get(self, "training_spec")

    @training_spec.setter
    def training_spec(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "training_spec", value)

    @property
    @pulumi.getter
    def uri(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The URI of the model version.
        """
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "uri", value)

    @property
    @pulumi.getter(name="versionDescription")
    def version_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The version descriptions.
        """
        return pulumi.get(self, "version_description")

    @version_description.setter
    def version_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_description", value)

    @property
    @pulumi.getter(name="versionName")
    def version_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Model version.
        """
        return pulumi.get(self, "version_name")

    @version_name.setter
    def version_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_name", value)


@pulumi.type_token("alicloud:pai/workspaceModelVersion:WorkspaceModelVersion")
class WorkspaceModelVersion(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 approval_status: Optional[pulumi.Input[builtins.str]] = None,
                 extra_info: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 format_type: Optional[pulumi.Input[builtins.str]] = None,
                 framework_type: Optional[pulumi.Input[builtins.str]] = None,
                 inference_spec: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceModelVersionLabelArgs', 'WorkspaceModelVersionLabelArgsDict']]]]] = None,
                 metrics: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 model_id: Optional[pulumi.Input[builtins.str]] = None,
                 options: Optional[pulumi.Input[builtins.str]] = None,
                 source_id: Optional[pulumi.Input[builtins.str]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 training_spec: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None,
                 version_description: Optional[pulumi.Input[builtins.str]] = None,
                 version_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a PAI Workspace Model Version resource.

        For information about PAI Workspace Model Version and how to use it, see [What is Model Version](https://next.api.alibabacloud.com/document/AIWorkSpace/2021-02-04/CreateModelVersion).

        > **NOTE:** Available since v1.248.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_di9fs_l = alicloud.pai.WorkspaceWorkspace("defaultDI9fsL",
            description="802",
            display_name=name,
            workspace_name=f"{name}_{default['result']}",
            env_types=["prod"])
        defaults_hpt_el = alicloud.pai.WorkspaceModel("defaultsHptEL",
            model_name=name,
            workspace_id=default_di9fs_l.id,
            origin="Civitai",
            task="text-to-image-synthesis",
            accessibility="PRIVATE",
            model_type="Checkpoint",
            order_number=1,
            model_description="ModelDescription.",
            model_doc="https://eas-***.oss-cn-hangzhou.aliyuncs.com/s**.safetensors",
            domain="aigc",
            labels=[{
                "key": "base_model",
                "value": "SD 1.5",
            }],
            extra_info={
                "test": "15",
            })
        default_workspace_model_version = alicloud.pai.WorkspaceModelVersion("default",
            version_description="VersionDescription.",
            source_type="TrainingService",
            source_id="region=${region},workspaceId=${workspace_id},kind=TrainingJob,id=job-id",
            extra_info={
                "test": "15",
            },
            training_spec={
                "test": "TrainingSpec",
            },
            uri="oss://hz-example-0701.oss-cn-hangzhou-internal.aliyuncs.com/checkpoints/",
            inference_spec={
                "test": "InferenceSpec",
            },
            model_id=defaults_hpt_el.id,
            format_type="SavedModel",
            approval_status="Pending",
            framework_type="PyTorch",
            version_name="1.0.0",
            metrics={},
            labels=[{
                "key": "k1",
                "value": "vs1",
            }])
        ```

        ## Import

        PAI Workspace Model Version can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:pai/workspaceModelVersion:WorkspaceModelVersion example <model_id>:<version_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] approval_status: The approval status. Valid values:
               - Pending: To be determined.
               - Approved: Allow to go online.
               - Rejected: Online is not allowed.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] extra_info: Other information.
        :param pulumi.Input[builtins.str] format_type: The format of the model. Valid values:
               - OfflineModel
               - SavedModel
               - Keras H5
               - Frozen Pb
               - Caffe Prototxt
               - TorchScript
               - XGBoost
               - PMML
               - AlinkModel
               - ONNX
        :param pulumi.Input[builtins.str] framework_type: The framework of the model. Valid values:
               - Pytorch
               - XGBoost
               - Keras
               - Caffe
               - Alink
               - Xflow
               - TensorFlow
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] inference_spec: Describes how to apply to downstream inference services.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceModelVersionLabelArgs', 'WorkspaceModelVersionLabelArgsDict']]]] labels: List of model version labels. See `labels` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] metrics: The metrics for the model. The serialized length is limited to 8192.
        :param pulumi.Input[builtins.str] model_id: The model ID.
        :param pulumi.Input[builtins.str] options: The extended field. This is a JSON string.
        :param pulumi.Input[builtins.str] source_id: The source ID.
        :param pulumi.Input[builtins.str] source_type: The type of the model source. Valid values:
               - Custom: Custom.
               - PAIFlow:PAI workflow.
               - TrainingService:PAI training service.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] training_spec: The training configurations. Used for fine-tuning and incremental training.
        :param pulumi.Input[builtins.str] uri: The URI of the model version.
        :param pulumi.Input[builtins.str] version_description: The version descriptions.
        :param pulumi.Input[builtins.str] version_name: The Model version.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WorkspaceModelVersionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a PAI Workspace Model Version resource.

        For information about PAI Workspace Model Version and how to use it, see [What is Model Version](https://next.api.alibabacloud.com/document/AIWorkSpace/2021-02-04/CreateModelVersion).

        > **NOTE:** Available since v1.248.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_di9fs_l = alicloud.pai.WorkspaceWorkspace("defaultDI9fsL",
            description="802",
            display_name=name,
            workspace_name=f"{name}_{default['result']}",
            env_types=["prod"])
        defaults_hpt_el = alicloud.pai.WorkspaceModel("defaultsHptEL",
            model_name=name,
            workspace_id=default_di9fs_l.id,
            origin="Civitai",
            task="text-to-image-synthesis",
            accessibility="PRIVATE",
            model_type="Checkpoint",
            order_number=1,
            model_description="ModelDescription.",
            model_doc="https://eas-***.oss-cn-hangzhou.aliyuncs.com/s**.safetensors",
            domain="aigc",
            labels=[{
                "key": "base_model",
                "value": "SD 1.5",
            }],
            extra_info={
                "test": "15",
            })
        default_workspace_model_version = alicloud.pai.WorkspaceModelVersion("default",
            version_description="VersionDescription.",
            source_type="TrainingService",
            source_id="region=${region},workspaceId=${workspace_id},kind=TrainingJob,id=job-id",
            extra_info={
                "test": "15",
            },
            training_spec={
                "test": "TrainingSpec",
            },
            uri="oss://hz-example-0701.oss-cn-hangzhou-internal.aliyuncs.com/checkpoints/",
            inference_spec={
                "test": "InferenceSpec",
            },
            model_id=defaults_hpt_el.id,
            format_type="SavedModel",
            approval_status="Pending",
            framework_type="PyTorch",
            version_name="1.0.0",
            metrics={},
            labels=[{
                "key": "k1",
                "value": "vs1",
            }])
        ```

        ## Import

        PAI Workspace Model Version can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:pai/workspaceModelVersion:WorkspaceModelVersion example <model_id>:<version_name>
        ```

        :param str resource_name: The name of the resource.
        :param WorkspaceModelVersionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceModelVersionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 approval_status: Optional[pulumi.Input[builtins.str]] = None,
                 extra_info: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 format_type: Optional[pulumi.Input[builtins.str]] = None,
                 framework_type: Optional[pulumi.Input[builtins.str]] = None,
                 inference_spec: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceModelVersionLabelArgs', 'WorkspaceModelVersionLabelArgsDict']]]]] = None,
                 metrics: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 model_id: Optional[pulumi.Input[builtins.str]] = None,
                 options: Optional[pulumi.Input[builtins.str]] = None,
                 source_id: Optional[pulumi.Input[builtins.str]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 training_spec: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None,
                 version_description: Optional[pulumi.Input[builtins.str]] = None,
                 version_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceModelVersionArgs.__new__(WorkspaceModelVersionArgs)

            __props__.__dict__["approval_status"] = approval_status
            __props__.__dict__["extra_info"] = extra_info
            __props__.__dict__["format_type"] = format_type
            __props__.__dict__["framework_type"] = framework_type
            __props__.__dict__["inference_spec"] = inference_spec
            __props__.__dict__["labels"] = labels
            __props__.__dict__["metrics"] = metrics
            if model_id is None and not opts.urn:
                raise TypeError("Missing required property 'model_id'")
            __props__.__dict__["model_id"] = model_id
            __props__.__dict__["options"] = options
            __props__.__dict__["source_id"] = source_id
            __props__.__dict__["source_type"] = source_type
            __props__.__dict__["training_spec"] = training_spec
            if uri is None and not opts.urn:
                raise TypeError("Missing required property 'uri'")
            __props__.__dict__["uri"] = uri
            __props__.__dict__["version_description"] = version_description
            __props__.__dict__["version_name"] = version_name
        super(WorkspaceModelVersion, __self__).__init__(
            'alicloud:pai/workspaceModelVersion:WorkspaceModelVersion',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            approval_status: Optional[pulumi.Input[builtins.str]] = None,
            extra_info: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            format_type: Optional[pulumi.Input[builtins.str]] = None,
            framework_type: Optional[pulumi.Input[builtins.str]] = None,
            inference_spec: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            labels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceModelVersionLabelArgs', 'WorkspaceModelVersionLabelArgsDict']]]]] = None,
            metrics: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            model_id: Optional[pulumi.Input[builtins.str]] = None,
            options: Optional[pulumi.Input[builtins.str]] = None,
            source_id: Optional[pulumi.Input[builtins.str]] = None,
            source_type: Optional[pulumi.Input[builtins.str]] = None,
            training_spec: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            uri: Optional[pulumi.Input[builtins.str]] = None,
            version_description: Optional[pulumi.Input[builtins.str]] = None,
            version_name: Optional[pulumi.Input[builtins.str]] = None) -> 'WorkspaceModelVersion':
        """
        Get an existing WorkspaceModelVersion resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] approval_status: The approval status. Valid values:
               - Pending: To be determined.
               - Approved: Allow to go online.
               - Rejected: Online is not allowed.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] extra_info: Other information.
        :param pulumi.Input[builtins.str] format_type: The format of the model. Valid values:
               - OfflineModel
               - SavedModel
               - Keras H5
               - Frozen Pb
               - Caffe Prototxt
               - TorchScript
               - XGBoost
               - PMML
               - AlinkModel
               - ONNX
        :param pulumi.Input[builtins.str] framework_type: The framework of the model. Valid values:
               - Pytorch
               - XGBoost
               - Keras
               - Caffe
               - Alink
               - Xflow
               - TensorFlow
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] inference_spec: Describes how to apply to downstream inference services.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceModelVersionLabelArgs', 'WorkspaceModelVersionLabelArgsDict']]]] labels: List of model version labels. See `labels` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] metrics: The metrics for the model. The serialized length is limited to 8192.
        :param pulumi.Input[builtins.str] model_id: The model ID.
        :param pulumi.Input[builtins.str] options: The extended field. This is a JSON string.
        :param pulumi.Input[builtins.str] source_id: The source ID.
        :param pulumi.Input[builtins.str] source_type: The type of the model source. Valid values:
               - Custom: Custom.
               - PAIFlow:PAI workflow.
               - TrainingService:PAI training service.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] training_spec: The training configurations. Used for fine-tuning and incremental training.
        :param pulumi.Input[builtins.str] uri: The URI of the model version.
        :param pulumi.Input[builtins.str] version_description: The version descriptions.
        :param pulumi.Input[builtins.str] version_name: The Model version.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceModelVersionState.__new__(_WorkspaceModelVersionState)

        __props__.__dict__["approval_status"] = approval_status
        __props__.__dict__["extra_info"] = extra_info
        __props__.__dict__["format_type"] = format_type
        __props__.__dict__["framework_type"] = framework_type
        __props__.__dict__["inference_spec"] = inference_spec
        __props__.__dict__["labels"] = labels
        __props__.__dict__["metrics"] = metrics
        __props__.__dict__["model_id"] = model_id
        __props__.__dict__["options"] = options
        __props__.__dict__["source_id"] = source_id
        __props__.__dict__["source_type"] = source_type
        __props__.__dict__["training_spec"] = training_spec
        __props__.__dict__["uri"] = uri
        __props__.__dict__["version_description"] = version_description
        __props__.__dict__["version_name"] = version_name
        return WorkspaceModelVersion(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="approvalStatus")
    def approval_status(self) -> pulumi.Output[builtins.str]:
        """
        The approval status. Valid values:
        - Pending: To be determined.
        - Approved: Allow to go online.
        - Rejected: Online is not allowed.
        """
        return pulumi.get(self, "approval_status")

    @property
    @pulumi.getter(name="extraInfo")
    def extra_info(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        Other information.
        """
        return pulumi.get(self, "extra_info")

    @property
    @pulumi.getter(name="formatType")
    def format_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The format of the model. Valid values:
        - OfflineModel
        - SavedModel
        - Keras H5
        - Frozen Pb
        - Caffe Prototxt
        - TorchScript
        - XGBoost
        - PMML
        - AlinkModel
        - ONNX
        """
        return pulumi.get(self, "format_type")

    @property
    @pulumi.getter(name="frameworkType")
    def framework_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The framework of the model. Valid values:
        - Pytorch
        - XGBoost
        - Keras
        - Caffe
        - Alink
        - Xflow
        - TensorFlow
        """
        return pulumi.get(self, "framework_type")

    @property
    @pulumi.getter(name="inferenceSpec")
    def inference_spec(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        Describes how to apply to downstream inference services.
        """
        return pulumi.get(self, "inference_spec")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Optional[Sequence['outputs.WorkspaceModelVersionLabel']]]:
        """
        List of model version labels. See `labels` below.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def metrics(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        The metrics for the model. The serialized length is limited to 8192.
        """
        return pulumi.get(self, "metrics")

    @property
    @pulumi.getter(name="modelId")
    def model_id(self) -> pulumi.Output[builtins.str]:
        """
        The model ID.
        """
        return pulumi.get(self, "model_id")

    @property
    @pulumi.getter
    def options(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The extended field. This is a JSON string.
        """
        return pulumi.get(self, "options")

    @property
    @pulumi.getter(name="sourceId")
    def source_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The source ID.
        """
        return pulumi.get(self, "source_id")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> pulumi.Output[builtins.str]:
        """
        The type of the model source. Valid values:
        - Custom: Custom.
        - PAIFlow:PAI workflow.
        - TrainingService:PAI training service.
        """
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter(name="trainingSpec")
    def training_spec(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        The training configurations. Used for fine-tuning and incremental training.
        """
        return pulumi.get(self, "training_spec")

    @property
    @pulumi.getter
    def uri(self) -> pulumi.Output[builtins.str]:
        """
        The URI of the model version.
        """
        return pulumi.get(self, "uri")

    @property
    @pulumi.getter(name="versionDescription")
    def version_description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The version descriptions.
        """
        return pulumi.get(self, "version_description")

    @property
    @pulumi.getter(name="versionName")
    def version_name(self) -> pulumi.Output[builtins.str]:
        """
        The Model version.
        """
        return pulumi.get(self, "version_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ExchangeArgs', 'Exchange']

@pulumi.input_type
class ExchangeArgs:
    def __init__(__self__, *,
                 auto_delete_state: pulumi.Input[builtins.bool],
                 exchange_name: pulumi.Input[builtins.str],
                 exchange_type: pulumi.Input[builtins.str],
                 instance_id: pulumi.Input[builtins.str],
                 internal: pulumi.Input[builtins.bool],
                 virtual_host_name: pulumi.Input[builtins.str],
                 alternate_exchange: Optional[pulumi.Input[builtins.str]] = None,
                 x_delayed_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Exchange resource.
        :param pulumi.Input[builtins.bool] auto_delete_state: Specifies whether to automatically delete the exchange. Valid values:
        :param pulumi.Input[builtins.str] exchange_name: The name of the exchange that you want to create. The exchange name must meet the following conventions:
               
               - The name must be 1 to 255 characters in length, and can contain only letters, digits, hyphens (-), underscores (\\_), periods (.), number signs (#), forward slashes (/), and at signs (@).
               - After the exchange is created, you cannot change its name. If you want to change its name, delete the exchange and create another exchange.
        :param pulumi.Input[builtins.str] exchange_type: The Exchange type. Value:
               - `DIRECT`: This type of Routing rule routes messages to a Queue whose Binding Key matches the Routing Key.
               - `TOPIC`: This type is similar to the DIRECT type. It uses Routing Key pattern matching and string comparison to route messages to the bound Queue.
               - `FANOUT`: This type of routing rule is very simple. It routes all messages sent to the Exchange to all queues bound to it, which is equivalent to the broadcast function.
               - `HEADERS`: This type is similar to the DIRECT type. Headers Exchange uses the Headers attribute instead of Routing Key for route matching. When binding Headers Exchange and Queue, the Key-value pair of the bound attribute is set. When sending a message to Headers Exchange, the Headers attribute Key-value pair of the message is set, and the message is routed to the bound Queue by comparing the Headers attribute Key-value pair with the bound attribute Key-value pair.
               - `X_delayed_message`: By declaring this type of Exchange, you can customize the Header attribute x-delay of the message to specify the delivery delay time period, in milliseconds. Messages will be delivered to the corresponding Queue after the time period defined in the x-delay according to the routing rules. The routing rule depends on the Exchange route type specified in the x-delayed-type.
               - `X_CONSISTENT_HASH`: The x-consistent-hash Exchange allows you to Hash the Routing Key or Header value and use the consistent hashing algorithm to route messages to different queues.
        :param pulumi.Input[builtins.str] instance_id: The ID of the ApsaraMQ for RabbitMQ instance whose exchange you want to delete.
        :param pulumi.Input[builtins.bool] internal: Specifies whether the exchange is an internal exchange. Valid values:
        :param pulumi.Input[builtins.str] virtual_host_name: The name of the vhost to which the exchange that you want to create belongs.
        :param pulumi.Input[builtins.str] alternate_exchange: The alternate exchange. An alternate exchange is used to receive messages that fail to be routed to queues from the current exchange.
        :param pulumi.Input[builtins.str] x_delayed_type: RabbitMQ supports the x-delayed-message Exchange. By declaring this type of Exchange, you can customize the x-delay header attribute to specify the delay period for message delivery, measured in milliseconds. The message will be delivered to the corresponding Queue after the period defined in x-delay. The routing rules are determined by the type of Exchange specified in x-delayed-type.
        """
        pulumi.set(__self__, "auto_delete_state", auto_delete_state)
        pulumi.set(__self__, "exchange_name", exchange_name)
        pulumi.set(__self__, "exchange_type", exchange_type)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "internal", internal)
        pulumi.set(__self__, "virtual_host_name", virtual_host_name)
        if alternate_exchange is not None:
            pulumi.set(__self__, "alternate_exchange", alternate_exchange)
        if x_delayed_type is not None:
            pulumi.set(__self__, "x_delayed_type", x_delayed_type)

    @property
    @pulumi.getter(name="autoDeleteState")
    def auto_delete_state(self) -> pulumi.Input[builtins.bool]:
        """
        Specifies whether to automatically delete the exchange. Valid values:
        """
        return pulumi.get(self, "auto_delete_state")

    @auto_delete_state.setter
    def auto_delete_state(self, value: pulumi.Input[builtins.bool]):
        pulumi.set(self, "auto_delete_state", value)

    @property
    @pulumi.getter(name="exchangeName")
    def exchange_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the exchange that you want to create. The exchange name must meet the following conventions:

        - The name must be 1 to 255 characters in length, and can contain only letters, digits, hyphens (-), underscores (\\_), periods (.), number signs (#), forward slashes (/), and at signs (@).
        - After the exchange is created, you cannot change its name. If you want to change its name, delete the exchange and create another exchange.
        """
        return pulumi.get(self, "exchange_name")

    @exchange_name.setter
    def exchange_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "exchange_name", value)

    @property
    @pulumi.getter(name="exchangeType")
    def exchange_type(self) -> pulumi.Input[builtins.str]:
        """
        The Exchange type. Value:
        - `DIRECT`: This type of Routing rule routes messages to a Queue whose Binding Key matches the Routing Key.
        - `TOPIC`: This type is similar to the DIRECT type. It uses Routing Key pattern matching and string comparison to route messages to the bound Queue.
        - `FANOUT`: This type of routing rule is very simple. It routes all messages sent to the Exchange to all queues bound to it, which is equivalent to the broadcast function.
        - `HEADERS`: This type is similar to the DIRECT type. Headers Exchange uses the Headers attribute instead of Routing Key for route matching. When binding Headers Exchange and Queue, the Key-value pair of the bound attribute is set. When sending a message to Headers Exchange, the Headers attribute Key-value pair of the message is set, and the message is routed to the bound Queue by comparing the Headers attribute Key-value pair with the bound attribute Key-value pair.
        - `X_delayed_message`: By declaring this type of Exchange, you can customize the Header attribute x-delay of the message to specify the delivery delay time period, in milliseconds. Messages will be delivered to the corresponding Queue after the time period defined in the x-delay according to the routing rules. The routing rule depends on the Exchange route type specified in the x-delayed-type.
        - `X_CONSISTENT_HASH`: The x-consistent-hash Exchange allows you to Hash the Routing Key or Header value and use the consistent hashing algorithm to route messages to different queues.
        """
        return pulumi.get(self, "exchange_type")

    @exchange_type.setter
    def exchange_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "exchange_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the ApsaraMQ for RabbitMQ instance whose exchange you want to delete.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def internal(self) -> pulumi.Input[builtins.bool]:
        """
        Specifies whether the exchange is an internal exchange. Valid values:
        """
        return pulumi.get(self, "internal")

    @internal.setter
    def internal(self, value: pulumi.Input[builtins.bool]):
        pulumi.set(self, "internal", value)

    @property
    @pulumi.getter(name="virtualHostName")
    def virtual_host_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the vhost to which the exchange that you want to create belongs.
        """
        return pulumi.get(self, "virtual_host_name")

    @virtual_host_name.setter
    def virtual_host_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "virtual_host_name", value)

    @property
    @pulumi.getter(name="alternateExchange")
    def alternate_exchange(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The alternate exchange. An alternate exchange is used to receive messages that fail to be routed to queues from the current exchange.
        """
        return pulumi.get(self, "alternate_exchange")

    @alternate_exchange.setter
    def alternate_exchange(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alternate_exchange", value)

    @property
    @pulumi.getter(name="xDelayedType")
    def x_delayed_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ supports the x-delayed-message Exchange. By declaring this type of Exchange, you can customize the x-delay header attribute to specify the delay period for message delivery, measured in milliseconds. The message will be delivered to the corresponding Queue after the period defined in x-delay. The routing rules are determined by the type of Exchange specified in x-delayed-type.
        """
        return pulumi.get(self, "x_delayed_type")

    @x_delayed_type.setter
    def x_delayed_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "x_delayed_type", value)


@pulumi.input_type
class _ExchangeState:
    def __init__(__self__, *,
                 alternate_exchange: Optional[pulumi.Input[builtins.str]] = None,
                 auto_delete_state: Optional[pulumi.Input[builtins.bool]] = None,
                 create_time: Optional[pulumi.Input[builtins.int]] = None,
                 exchange_name: Optional[pulumi.Input[builtins.str]] = None,
                 exchange_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 internal: Optional[pulumi.Input[builtins.bool]] = None,
                 virtual_host_name: Optional[pulumi.Input[builtins.str]] = None,
                 x_delayed_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Exchange resources.
        :param pulumi.Input[builtins.str] alternate_exchange: The alternate exchange. An alternate exchange is used to receive messages that fail to be routed to queues from the current exchange.
        :param pulumi.Input[builtins.bool] auto_delete_state: Specifies whether to automatically delete the exchange. Valid values:
        :param pulumi.Input[builtins.int] create_time: CreateTime
        :param pulumi.Input[builtins.str] exchange_name: The name of the exchange that you want to create. The exchange name must meet the following conventions:
               
               - The name must be 1 to 255 characters in length, and can contain only letters, digits, hyphens (-), underscores (\\_), periods (.), number signs (#), forward slashes (/), and at signs (@).
               - After the exchange is created, you cannot change its name. If you want to change its name, delete the exchange and create another exchange.
        :param pulumi.Input[builtins.str] exchange_type: The Exchange type. Value:
               - `DIRECT`: This type of Routing rule routes messages to a Queue whose Binding Key matches the Routing Key.
               - `TOPIC`: This type is similar to the DIRECT type. It uses Routing Key pattern matching and string comparison to route messages to the bound Queue.
               - `FANOUT`: This type of routing rule is very simple. It routes all messages sent to the Exchange to all queues bound to it, which is equivalent to the broadcast function.
               - `HEADERS`: This type is similar to the DIRECT type. Headers Exchange uses the Headers attribute instead of Routing Key for route matching. When binding Headers Exchange and Queue, the Key-value pair of the bound attribute is set. When sending a message to Headers Exchange, the Headers attribute Key-value pair of the message is set, and the message is routed to the bound Queue by comparing the Headers attribute Key-value pair with the bound attribute Key-value pair.
               - `X_delayed_message`: By declaring this type of Exchange, you can customize the Header attribute x-delay of the message to specify the delivery delay time period, in milliseconds. Messages will be delivered to the corresponding Queue after the time period defined in the x-delay according to the routing rules. The routing rule depends on the Exchange route type specified in the x-delayed-type.
               - `X_CONSISTENT_HASH`: The x-consistent-hash Exchange allows you to Hash the Routing Key or Header value and use the consistent hashing algorithm to route messages to different queues.
        :param pulumi.Input[builtins.str] instance_id: The ID of the ApsaraMQ for RabbitMQ instance whose exchange you want to delete.
        :param pulumi.Input[builtins.bool] internal: Specifies whether the exchange is an internal exchange. Valid values:
        :param pulumi.Input[builtins.str] virtual_host_name: The name of the vhost to which the exchange that you want to create belongs.
        :param pulumi.Input[builtins.str] x_delayed_type: RabbitMQ supports the x-delayed-message Exchange. By declaring this type of Exchange, you can customize the x-delay header attribute to specify the delay period for message delivery, measured in milliseconds. The message will be delivered to the corresponding Queue after the period defined in x-delay. The routing rules are determined by the type of Exchange specified in x-delayed-type.
        """
        if alternate_exchange is not None:
            pulumi.set(__self__, "alternate_exchange", alternate_exchange)
        if auto_delete_state is not None:
            pulumi.set(__self__, "auto_delete_state", auto_delete_state)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if exchange_name is not None:
            pulumi.set(__self__, "exchange_name", exchange_name)
        if exchange_type is not None:
            pulumi.set(__self__, "exchange_type", exchange_type)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if internal is not None:
            pulumi.set(__self__, "internal", internal)
        if virtual_host_name is not None:
            pulumi.set(__self__, "virtual_host_name", virtual_host_name)
        if x_delayed_type is not None:
            pulumi.set(__self__, "x_delayed_type", x_delayed_type)

    @property
    @pulumi.getter(name="alternateExchange")
    def alternate_exchange(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The alternate exchange. An alternate exchange is used to receive messages that fail to be routed to queues from the current exchange.
        """
        return pulumi.get(self, "alternate_exchange")

    @alternate_exchange.setter
    def alternate_exchange(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alternate_exchange", value)

    @property
    @pulumi.getter(name="autoDeleteState")
    def auto_delete_state(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to automatically delete the exchange. Valid values:
        """
        return pulumi.get(self, "auto_delete_state")

    @auto_delete_state.setter
    def auto_delete_state(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_delete_state", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        CreateTime
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="exchangeName")
    def exchange_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the exchange that you want to create. The exchange name must meet the following conventions:

        - The name must be 1 to 255 characters in length, and can contain only letters, digits, hyphens (-), underscores (\\_), periods (.), number signs (#), forward slashes (/), and at signs (@).
        - After the exchange is created, you cannot change its name. If you want to change its name, delete the exchange and create another exchange.
        """
        return pulumi.get(self, "exchange_name")

    @exchange_name.setter
    def exchange_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exchange_name", value)

    @property
    @pulumi.getter(name="exchangeType")
    def exchange_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Exchange type. Value:
        - `DIRECT`: This type of Routing rule routes messages to a Queue whose Binding Key matches the Routing Key.
        - `TOPIC`: This type is similar to the DIRECT type. It uses Routing Key pattern matching and string comparison to route messages to the bound Queue.
        - `FANOUT`: This type of routing rule is very simple. It routes all messages sent to the Exchange to all queues bound to it, which is equivalent to the broadcast function.
        - `HEADERS`: This type is similar to the DIRECT type. Headers Exchange uses the Headers attribute instead of Routing Key for route matching. When binding Headers Exchange and Queue, the Key-value pair of the bound attribute is set. When sending a message to Headers Exchange, the Headers attribute Key-value pair of the message is set, and the message is routed to the bound Queue by comparing the Headers attribute Key-value pair with the bound attribute Key-value pair.
        - `X_delayed_message`: By declaring this type of Exchange, you can customize the Header attribute x-delay of the message to specify the delivery delay time period, in milliseconds. Messages will be delivered to the corresponding Queue after the time period defined in the x-delay according to the routing rules. The routing rule depends on the Exchange route type specified in the x-delayed-type.
        - `X_CONSISTENT_HASH`: The x-consistent-hash Exchange allows you to Hash the Routing Key or Header value and use the consistent hashing algorithm to route messages to different queues.
        """
        return pulumi.get(self, "exchange_type")

    @exchange_type.setter
    def exchange_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exchange_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the ApsaraMQ for RabbitMQ instance whose exchange you want to delete.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def internal(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether the exchange is an internal exchange. Valid values:
        """
        return pulumi.get(self, "internal")

    @internal.setter
    def internal(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "internal", value)

    @property
    @pulumi.getter(name="virtualHostName")
    def virtual_host_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the vhost to which the exchange that you want to create belongs.
        """
        return pulumi.get(self, "virtual_host_name")

    @virtual_host_name.setter
    def virtual_host_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "virtual_host_name", value)

    @property
    @pulumi.getter(name="xDelayedType")
    def x_delayed_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RabbitMQ supports the x-delayed-message Exchange. By declaring this type of Exchange, you can customize the x-delay header attribute to specify the delay period for message delivery, measured in milliseconds. The message will be delivered to the corresponding Queue after the period defined in x-delay. The routing rules are determined by the type of Exchange specified in x-delayed-type.
        """
        return pulumi.get(self, "x_delayed_type")

    @x_delayed_type.setter
    def x_delayed_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "x_delayed_type", value)


@pulumi.type_token("alicloud:amqp/exchange:Exchange")
class Exchange(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alternate_exchange: Optional[pulumi.Input[builtins.str]] = None,
                 auto_delete_state: Optional[pulumi.Input[builtins.bool]] = None,
                 exchange_name: Optional[pulumi.Input[builtins.str]] = None,
                 exchange_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 internal: Optional[pulumi.Input[builtins.bool]] = None,
                 virtual_host_name: Optional[pulumi.Input[builtins.str]] = None,
                 x_delayed_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a RabbitMQ (AMQP) Exchange resource.

        For information about RabbitMQ (AMQP) Exchange and how to use it, see [What is Exchange](https://www.alibabacloud.com/help/en/message-queue-for-rabbitmq/latest/createexchange).

        > **NOTE:** Available since v1.128.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        virtual_host_name = config.get("virtualHostName")
        if virtual_host_name is None:
            virtual_host_name = "/"
        create_instance = alicloud.amqp.Instance("CreateInstance",
            renewal_duration=1,
            max_tps="3000",
            period_cycle="Month",
            max_connections=2000,
            support_eip=True,
            auto_renew=False,
            renewal_status="AutoRenewal",
            period=12,
            instance_name=name,
            support_tracing=False,
            payment_type="Subscription",
            renewal_duration_unit="Month",
            instance_type="enterprise",
            queue_capacity="200",
            max_eip_tps="128",
            storage_size="0")
        default = alicloud.amqp.Exchange("default",
            virtual_host_name=virtual_host_name,
            instance_id=create_instance.id,
            internal=True,
            auto_delete_state=False,
            exchange_name=name,
            exchange_type="X_CONSISTENT_HASH",
            alternate_exchange="bakExchange",
            x_delayed_type="DIRECT")
        ```

        ## Import

        RabbitMQ (AMQP) Exchange can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:amqp/exchange:Exchange example <instance_id>:<virtual_host_name>:<exchange_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] alternate_exchange: The alternate exchange. An alternate exchange is used to receive messages that fail to be routed to queues from the current exchange.
        :param pulumi.Input[builtins.bool] auto_delete_state: Specifies whether to automatically delete the exchange. Valid values:
        :param pulumi.Input[builtins.str] exchange_name: The name of the exchange that you want to create. The exchange name must meet the following conventions:
               
               - The name must be 1 to 255 characters in length, and can contain only letters, digits, hyphens (-), underscores (\\_), periods (.), number signs (#), forward slashes (/), and at signs (@).
               - After the exchange is created, you cannot change its name. If you want to change its name, delete the exchange and create another exchange.
        :param pulumi.Input[builtins.str] exchange_type: The Exchange type. Value:
               - `DIRECT`: This type of Routing rule routes messages to a Queue whose Binding Key matches the Routing Key.
               - `TOPIC`: This type is similar to the DIRECT type. It uses Routing Key pattern matching and string comparison to route messages to the bound Queue.
               - `FANOUT`: This type of routing rule is very simple. It routes all messages sent to the Exchange to all queues bound to it, which is equivalent to the broadcast function.
               - `HEADERS`: This type is similar to the DIRECT type. Headers Exchange uses the Headers attribute instead of Routing Key for route matching. When binding Headers Exchange and Queue, the Key-value pair of the bound attribute is set. When sending a message to Headers Exchange, the Headers attribute Key-value pair of the message is set, and the message is routed to the bound Queue by comparing the Headers attribute Key-value pair with the bound attribute Key-value pair.
               - `X_delayed_message`: By declaring this type of Exchange, you can customize the Header attribute x-delay of the message to specify the delivery delay time period, in milliseconds. Messages will be delivered to the corresponding Queue after the time period defined in the x-delay according to the routing rules. The routing rule depends on the Exchange route type specified in the x-delayed-type.
               - `X_CONSISTENT_HASH`: The x-consistent-hash Exchange allows you to Hash the Routing Key or Header value and use the consistent hashing algorithm to route messages to different queues.
        :param pulumi.Input[builtins.str] instance_id: The ID of the ApsaraMQ for RabbitMQ instance whose exchange you want to delete.
        :param pulumi.Input[builtins.bool] internal: Specifies whether the exchange is an internal exchange. Valid values:
        :param pulumi.Input[builtins.str] virtual_host_name: The name of the vhost to which the exchange that you want to create belongs.
        :param pulumi.Input[builtins.str] x_delayed_type: RabbitMQ supports the x-delayed-message Exchange. By declaring this type of Exchange, you can customize the x-delay header attribute to specify the delay period for message delivery, measured in milliseconds. The message will be delivered to the corresponding Queue after the period defined in x-delay. The routing rules are determined by the type of Exchange specified in x-delayed-type.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ExchangeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a RabbitMQ (AMQP) Exchange resource.

        For information about RabbitMQ (AMQP) Exchange and how to use it, see [What is Exchange](https://www.alibabacloud.com/help/en/message-queue-for-rabbitmq/latest/createexchange).

        > **NOTE:** Available since v1.128.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        virtual_host_name = config.get("virtualHostName")
        if virtual_host_name is None:
            virtual_host_name = "/"
        create_instance = alicloud.amqp.Instance("CreateInstance",
            renewal_duration=1,
            max_tps="3000",
            period_cycle="Month",
            max_connections=2000,
            support_eip=True,
            auto_renew=False,
            renewal_status="AutoRenewal",
            period=12,
            instance_name=name,
            support_tracing=False,
            payment_type="Subscription",
            renewal_duration_unit="Month",
            instance_type="enterprise",
            queue_capacity="200",
            max_eip_tps="128",
            storage_size="0")
        default = alicloud.amqp.Exchange("default",
            virtual_host_name=virtual_host_name,
            instance_id=create_instance.id,
            internal=True,
            auto_delete_state=False,
            exchange_name=name,
            exchange_type="X_CONSISTENT_HASH",
            alternate_exchange="bakExchange",
            x_delayed_type="DIRECT")
        ```

        ## Import

        RabbitMQ (AMQP) Exchange can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:amqp/exchange:Exchange example <instance_id>:<virtual_host_name>:<exchange_name>
        ```

        :param str resource_name: The name of the resource.
        :param ExchangeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ExchangeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alternate_exchange: Optional[pulumi.Input[builtins.str]] = None,
                 auto_delete_state: Optional[pulumi.Input[builtins.bool]] = None,
                 exchange_name: Optional[pulumi.Input[builtins.str]] = None,
                 exchange_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 internal: Optional[pulumi.Input[builtins.bool]] = None,
                 virtual_host_name: Optional[pulumi.Input[builtins.str]] = None,
                 x_delayed_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ExchangeArgs.__new__(ExchangeArgs)

            __props__.__dict__["alternate_exchange"] = alternate_exchange
            if auto_delete_state is None and not opts.urn:
                raise TypeError("Missing required property 'auto_delete_state'")
            __props__.__dict__["auto_delete_state"] = auto_delete_state
            if exchange_name is None and not opts.urn:
                raise TypeError("Missing required property 'exchange_name'")
            __props__.__dict__["exchange_name"] = exchange_name
            if exchange_type is None and not opts.urn:
                raise TypeError("Missing required property 'exchange_type'")
            __props__.__dict__["exchange_type"] = exchange_type
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            if internal is None and not opts.urn:
                raise TypeError("Missing required property 'internal'")
            __props__.__dict__["internal"] = internal
            if virtual_host_name is None and not opts.urn:
                raise TypeError("Missing required property 'virtual_host_name'")
            __props__.__dict__["virtual_host_name"] = virtual_host_name
            __props__.__dict__["x_delayed_type"] = x_delayed_type
            __props__.__dict__["create_time"] = None
        super(Exchange, __self__).__init__(
            'alicloud:amqp/exchange:Exchange',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alternate_exchange: Optional[pulumi.Input[builtins.str]] = None,
            auto_delete_state: Optional[pulumi.Input[builtins.bool]] = None,
            create_time: Optional[pulumi.Input[builtins.int]] = None,
            exchange_name: Optional[pulumi.Input[builtins.str]] = None,
            exchange_type: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            internal: Optional[pulumi.Input[builtins.bool]] = None,
            virtual_host_name: Optional[pulumi.Input[builtins.str]] = None,
            x_delayed_type: Optional[pulumi.Input[builtins.str]] = None) -> 'Exchange':
        """
        Get an existing Exchange resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] alternate_exchange: The alternate exchange. An alternate exchange is used to receive messages that fail to be routed to queues from the current exchange.
        :param pulumi.Input[builtins.bool] auto_delete_state: Specifies whether to automatically delete the exchange. Valid values:
        :param pulumi.Input[builtins.int] create_time: CreateTime
        :param pulumi.Input[builtins.str] exchange_name: The name of the exchange that you want to create. The exchange name must meet the following conventions:
               
               - The name must be 1 to 255 characters in length, and can contain only letters, digits, hyphens (-), underscores (\\_), periods (.), number signs (#), forward slashes (/), and at signs (@).
               - After the exchange is created, you cannot change its name. If you want to change its name, delete the exchange and create another exchange.
        :param pulumi.Input[builtins.str] exchange_type: The Exchange type. Value:
               - `DIRECT`: This type of Routing rule routes messages to a Queue whose Binding Key matches the Routing Key.
               - `TOPIC`: This type is similar to the DIRECT type. It uses Routing Key pattern matching and string comparison to route messages to the bound Queue.
               - `FANOUT`: This type of routing rule is very simple. It routes all messages sent to the Exchange to all queues bound to it, which is equivalent to the broadcast function.
               - `HEADERS`: This type is similar to the DIRECT type. Headers Exchange uses the Headers attribute instead of Routing Key for route matching. When binding Headers Exchange and Queue, the Key-value pair of the bound attribute is set. When sending a message to Headers Exchange, the Headers attribute Key-value pair of the message is set, and the message is routed to the bound Queue by comparing the Headers attribute Key-value pair with the bound attribute Key-value pair.
               - `X_delayed_message`: By declaring this type of Exchange, you can customize the Header attribute x-delay of the message to specify the delivery delay time period, in milliseconds. Messages will be delivered to the corresponding Queue after the time period defined in the x-delay according to the routing rules. The routing rule depends on the Exchange route type specified in the x-delayed-type.
               - `X_CONSISTENT_HASH`: The x-consistent-hash Exchange allows you to Hash the Routing Key or Header value and use the consistent hashing algorithm to route messages to different queues.
        :param pulumi.Input[builtins.str] instance_id: The ID of the ApsaraMQ for RabbitMQ instance whose exchange you want to delete.
        :param pulumi.Input[builtins.bool] internal: Specifies whether the exchange is an internal exchange. Valid values:
        :param pulumi.Input[builtins.str] virtual_host_name: The name of the vhost to which the exchange that you want to create belongs.
        :param pulumi.Input[builtins.str] x_delayed_type: RabbitMQ supports the x-delayed-message Exchange. By declaring this type of Exchange, you can customize the x-delay header attribute to specify the delay period for message delivery, measured in milliseconds. The message will be delivered to the corresponding Queue after the period defined in x-delay. The routing rules are determined by the type of Exchange specified in x-delayed-type.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ExchangeState.__new__(_ExchangeState)

        __props__.__dict__["alternate_exchange"] = alternate_exchange
        __props__.__dict__["auto_delete_state"] = auto_delete_state
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["exchange_name"] = exchange_name
        __props__.__dict__["exchange_type"] = exchange_type
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["internal"] = internal
        __props__.__dict__["virtual_host_name"] = virtual_host_name
        __props__.__dict__["x_delayed_type"] = x_delayed_type
        return Exchange(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="alternateExchange")
    def alternate_exchange(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The alternate exchange. An alternate exchange is used to receive messages that fail to be routed to queues from the current exchange.
        """
        return pulumi.get(self, "alternate_exchange")

    @property
    @pulumi.getter(name="autoDeleteState")
    def auto_delete_state(self) -> pulumi.Output[builtins.bool]:
        """
        Specifies whether to automatically delete the exchange. Valid values:
        """
        return pulumi.get(self, "auto_delete_state")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.int]:
        """
        CreateTime
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="exchangeName")
    def exchange_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the exchange that you want to create. The exchange name must meet the following conventions:

        - The name must be 1 to 255 characters in length, and can contain only letters, digits, hyphens (-), underscores (\\_), periods (.), number signs (#), forward slashes (/), and at signs (@).
        - After the exchange is created, you cannot change its name. If you want to change its name, delete the exchange and create another exchange.
        """
        return pulumi.get(self, "exchange_name")

    @property
    @pulumi.getter(name="exchangeType")
    def exchange_type(self) -> pulumi.Output[builtins.str]:
        """
        The Exchange type. Value:
        - `DIRECT`: This type of Routing rule routes messages to a Queue whose Binding Key matches the Routing Key.
        - `TOPIC`: This type is similar to the DIRECT type. It uses Routing Key pattern matching and string comparison to route messages to the bound Queue.
        - `FANOUT`: This type of routing rule is very simple. It routes all messages sent to the Exchange to all queues bound to it, which is equivalent to the broadcast function.
        - `HEADERS`: This type is similar to the DIRECT type. Headers Exchange uses the Headers attribute instead of Routing Key for route matching. When binding Headers Exchange and Queue, the Key-value pair of the bound attribute is set. When sending a message to Headers Exchange, the Headers attribute Key-value pair of the message is set, and the message is routed to the bound Queue by comparing the Headers attribute Key-value pair with the bound attribute Key-value pair.
        - `X_delayed_message`: By declaring this type of Exchange, you can customize the Header attribute x-delay of the message to specify the delivery delay time period, in milliseconds. Messages will be delivered to the corresponding Queue after the time period defined in the x-delay according to the routing rules. The routing rule depends on the Exchange route type specified in the x-delayed-type.
        - `X_CONSISTENT_HASH`: The x-consistent-hash Exchange allows you to Hash the Routing Key or Header value and use the consistent hashing algorithm to route messages to different queues.
        """
        return pulumi.get(self, "exchange_type")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the ApsaraMQ for RabbitMQ instance whose exchange you want to delete.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def internal(self) -> pulumi.Output[builtins.bool]:
        """
        Specifies whether the exchange is an internal exchange. Valid values:
        """
        return pulumi.get(self, "internal")

    @property
    @pulumi.getter(name="virtualHostName")
    def virtual_host_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the vhost to which the exchange that you want to create belongs.
        """
        return pulumi.get(self, "virtual_host_name")

    @property
    @pulumi.getter(name="xDelayedType")
    def x_delayed_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        RabbitMQ supports the x-delayed-message Exchange. By declaring this type of Exchange, you can customize the x-delay header attribute to specify the delay period for message delivery, measured in milliseconds. The message will be delivered to the corresponding Queue after the period defined in x-delay. The routing rules are determined by the type of Exchange specified in x-delayed-type.
        """
        return pulumi.get(self, "x_delayed_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['BucketHttpsConfigArgs', 'BucketHttpsConfig']

@pulumi.input_type
class BucketHttpsConfigArgs:
    def __init__(__self__, *,
                 bucket: pulumi.Input[builtins.str],
                 enable: pulumi.Input[builtins.bool],
                 tls_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a BucketHttpsConfig resource.
        :param pulumi.Input[builtins.str] bucket: The name of the bucket.
        :param pulumi.Input[builtins.bool] enable: Specifies whether to enable TLS version management for the bucket. Valid values: true, false.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tls_versions: Specifies the TLS versions allowed to access this buckets.
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "enable", enable)
        if tls_versions is not None:
            pulumi.set(__self__, "tls_versions", tls_versions)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[builtins.str]:
        """
        The name of the bucket.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter
    def enable(self) -> pulumi.Input[builtins.bool]:
        """
        Specifies whether to enable TLS version management for the bucket. Valid values: true, false.
        """
        return pulumi.get(self, "enable")

    @enable.setter
    def enable(self, value: pulumi.Input[builtins.bool]):
        pulumi.set(self, "enable", value)

    @property
    @pulumi.getter(name="tlsVersions")
    def tls_versions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Specifies the TLS versions allowed to access this buckets.
        """
        return pulumi.get(self, "tls_versions")

    @tls_versions.setter
    def tls_versions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tls_versions", value)


@pulumi.input_type
class _BucketHttpsConfigState:
    def __init__(__self__, *,
                 bucket: Optional[pulumi.Input[builtins.str]] = None,
                 enable: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering BucketHttpsConfig resources.
        :param pulumi.Input[builtins.str] bucket: The name of the bucket.
        :param pulumi.Input[builtins.bool] enable: Specifies whether to enable TLS version management for the bucket. Valid values: true, false.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tls_versions: Specifies the TLS versions allowed to access this buckets.
        """
        if bucket is not None:
            pulumi.set(__self__, "bucket", bucket)
        if enable is not None:
            pulumi.set(__self__, "enable", enable)
        if tls_versions is not None:
            pulumi.set(__self__, "tls_versions", tls_versions)

    @property
    @pulumi.getter
    def bucket(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the bucket.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter
    def enable(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to enable TLS version management for the bucket. Valid values: true, false.
        """
        return pulumi.get(self, "enable")

    @enable.setter
    def enable(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable", value)

    @property
    @pulumi.getter(name="tlsVersions")
    def tls_versions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Specifies the TLS versions allowed to access this buckets.
        """
        return pulumi.get(self, "tls_versions")

    @tls_versions.setter
    def tls_versions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tls_versions", value)


@pulumi.type_token("alicloud:oss/bucketHttpsConfig:BucketHttpsConfig")
class BucketHttpsConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[builtins.str]] = None,
                 enable: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        ## Import

        OSS Bucket Https Config can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:oss/bucketHttpsConfig:BucketHttpsConfig example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] bucket: The name of the bucket.
        :param pulumi.Input[builtins.bool] enable: Specifies whether to enable TLS version management for the bucket. Valid values: true, false.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tls_versions: Specifies the TLS versions allowed to access this buckets.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BucketHttpsConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        OSS Bucket Https Config can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:oss/bucketHttpsConfig:BucketHttpsConfig example <id>
        ```

        :param str resource_name: The name of the resource.
        :param BucketHttpsConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BucketHttpsConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[builtins.str]] = None,
                 enable: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BucketHttpsConfigArgs.__new__(BucketHttpsConfigArgs)

            if bucket is None and not opts.urn:
                raise TypeError("Missing required property 'bucket'")
            __props__.__dict__["bucket"] = bucket
            if enable is None and not opts.urn:
                raise TypeError("Missing required property 'enable'")
            __props__.__dict__["enable"] = enable
            __props__.__dict__["tls_versions"] = tls_versions
        super(BucketHttpsConfig, __self__).__init__(
            'alicloud:oss/bucketHttpsConfig:BucketHttpsConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bucket: Optional[pulumi.Input[builtins.str]] = None,
            enable: Optional[pulumi.Input[builtins.bool]] = None,
            tls_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'BucketHttpsConfig':
        """
        Get an existing BucketHttpsConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] bucket: The name of the bucket.
        :param pulumi.Input[builtins.bool] enable: Specifies whether to enable TLS version management for the bucket. Valid values: true, false.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tls_versions: Specifies the TLS versions allowed to access this buckets.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BucketHttpsConfigState.__new__(_BucketHttpsConfigState)

        __props__.__dict__["bucket"] = bucket
        __props__.__dict__["enable"] = enable
        __props__.__dict__["tls_versions"] = tls_versions
        return BucketHttpsConfig(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Output[builtins.str]:
        """
        The name of the bucket.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter
    def enable(self) -> pulumi.Output[builtins.bool]:
        """
        Specifies whether to enable TLS version management for the bucket. Valid values: true, false.
        """
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter(name="tlsVersions")
    def tls_versions(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Specifies the TLS versions allowed to access this buckets.
        """
        return pulumi.get(self, "tls_versions")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetEcsSnapshotGroupsResult',
    'AwaitableGetEcsSnapshotGroupsResult',
    'get_ecs_snapshot_groups',
    'get_ecs_snapshot_groups_output',
]

@pulumi.output_type
class GetEcsSnapshotGroupsResult:
    """
    A collection of values returned by getEcsSnapshotGroups.
    """
    def __init__(__self__, groups=None, id=None, ids=None, instance_id=None, name_regex=None, names=None, output_file=None, snapshot_group_name=None, status=None, tags=None):
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if snapshot_group_name and not isinstance(snapshot_group_name, str):
            raise TypeError("Expected argument 'snapshot_group_name' to be a str")
        pulumi.set(__self__, "snapshot_group_name", snapshot_group_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def groups(self) -> Sequence['outputs.GetEcsSnapshotGroupsGroupResult']:
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="snapshotGroupName")
    def snapshot_group_name(self) -> Optional[builtins.str]:
        return pulumi.get(self, "snapshot_group_name")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, builtins.str]]:
        return pulumi.get(self, "tags")


class AwaitableGetEcsSnapshotGroupsResult(GetEcsSnapshotGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEcsSnapshotGroupsResult(
            groups=self.groups,
            id=self.id,
            ids=self.ids,
            instance_id=self.instance_id,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            snapshot_group_name=self.snapshot_group_name,
            status=self.status,
            tags=self.tags)


def get_ecs_snapshot_groups(ids: Optional[Sequence[builtins.str]] = None,
                            instance_id: Optional[builtins.str] = None,
                            name_regex: Optional[builtins.str] = None,
                            output_file: Optional[builtins.str] = None,
                            snapshot_group_name: Optional[builtins.str] = None,
                            status: Optional[builtins.str] = None,
                            tags: Optional[Mapping[str, builtins.str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEcsSnapshotGroupsResult:
    """
    This data source provides the Ecs Snapshot Groups of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.160.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ecs.get_ecs_snapshot_groups(ids=["example-id"])
    pulumi.export("ecsSnapshotGroupId1", ids.groups[0].id)
    name_regex = alicloud.ecs.get_ecs_snapshot_groups(name_regex="^my-SnapshotGroup")
    pulumi.export("ecsSnapshotGroupId2", name_regex.groups[0].id)
    status = alicloud.ecs.get_ecs_snapshot_groups(status="accomplished")
    pulumi.export("ecsSnapshotGroupId3", status.groups[0].id)
    instance_id = alicloud.ecs.get_ecs_snapshot_groups(instance_id="example-instance_id")
    pulumi.export("ecsSnapshotGroupId4", instance_id.groups[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Snapshot Group IDs.
    :param builtins.str instance_id: The ID of the instance.
    :param builtins.str name_regex: A regex string to filter results by Snapshot Group name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str snapshot_group_name: The name of the snapshot-consistent group.
    :param builtins.str status: The state of snapshot-consistent group. Valid Values: `accomplished`, `failed` and `progressing`.
    :param Mapping[str, builtins.str] tags: A mapping of tags to assign to the snapshot group.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['instanceId'] = instance_id
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['snapshotGroupName'] = snapshot_group_name
    __args__['status'] = status
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ecs/getEcsSnapshotGroups:getEcsSnapshotGroups', __args__, opts=opts, typ=GetEcsSnapshotGroupsResult).value

    return AwaitableGetEcsSnapshotGroupsResult(
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        snapshot_group_name=pulumi.get(__ret__, 'snapshot_group_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'))
def get_ecs_snapshot_groups_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                   instance_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                   name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                   output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                   snapshot_group_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                   status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                   tags: Optional[pulumi.Input[Optional[Mapping[str, builtins.str]]]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEcsSnapshotGroupsResult]:
    """
    This data source provides the Ecs Snapshot Groups of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.160.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ecs.get_ecs_snapshot_groups(ids=["example-id"])
    pulumi.export("ecsSnapshotGroupId1", ids.groups[0].id)
    name_regex = alicloud.ecs.get_ecs_snapshot_groups(name_regex="^my-SnapshotGroup")
    pulumi.export("ecsSnapshotGroupId2", name_regex.groups[0].id)
    status = alicloud.ecs.get_ecs_snapshot_groups(status="accomplished")
    pulumi.export("ecsSnapshotGroupId3", status.groups[0].id)
    instance_id = alicloud.ecs.get_ecs_snapshot_groups(instance_id="example-instance_id")
    pulumi.export("ecsSnapshotGroupId4", instance_id.groups[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Snapshot Group IDs.
    :param builtins.str instance_id: The ID of the instance.
    :param builtins.str name_regex: A regex string to filter results by Snapshot Group name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str snapshot_group_name: The name of the snapshot-consistent group.
    :param builtins.str status: The state of snapshot-consistent group. Valid Values: `accomplished`, `failed` and `progressing`.
    :param Mapping[str, builtins.str] tags: A mapping of tags to assign to the snapshot group.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['instanceId'] = instance_id
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['snapshotGroupName'] = snapshot_group_name
    __args__['status'] = status
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ecs/getEcsSnapshotGroups:getEcsSnapshotGroups', __args__, opts=opts, typ=GetEcsSnapshotGroupsResult)
    return __ret__.apply(lambda __response__: GetEcsSnapshotGroupsResult(
        groups=pulumi.get(__response__, 'groups'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        snapshot_group_name=pulumi.get(__response__, 'snapshot_group_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags')))
